@@ -1,6 +1,6 @@
 package AnyEvent::Beanstalk;
-BEGIN {
-  $AnyEvent::Beanstalk::VERSION = '1.110490';
+{
+  $AnyEvent::Beanstalk::VERSION = '1.121460';
 }
 
 use strict;
@@ -400,7 +400,7 @@ sub use {
   $self->run_cmd(
     'use' => $tube,
     sub {
-      $self->{__using} = $_[1] if @_ and $_[0] eq 'USING';
+      $self->{__using} = $_[0] if @_ and $_[1] =~ /^USING/;
       $cb[0]->(@_) if @cb;
     }
   );
@@ -466,7 +466,7 @@ sub watch {
   $self->run_cmd(
     'watch' => $tube,
     sub {
-      $self->{__watching}{$tube} = 1 if @_ and $_[0] eq 'WATCHING';
+      $self->{__watching}{$tube} = 1 if @_ and $_[1] =~ /^WATCHING/;
       $cb[0]->(@_) if @cb;
     }
   );
@@ -481,7 +481,7 @@ sub ignore {
   $self->run_cmd(
     'ignore' => $tube,
     sub {
-      delete $self->{__watching}{$tube} if @_ and $_[0] eq 'WATCHING';
+      delete $self->{__watching}{$tube} if @_ and $_[1] =~ /^WATCHING/;
       $cb[0]->(@_) if @cb;
     }
   );
@@ -556,7 +556,7 @@ sub pause_tube {
 
 sub watching {
   my $self = shift;
-  return unless $self->{sock};
+  return unless $self->{_sock};
   my $watching = $self->{__watching} or return;
   return keys %$watching;
 }
@@ -587,7 +587,7 @@ AnyEvent::Beanstalk - Async client to talk to beanstalkd server
 
 =head1 VERSION
 
-version 1.110490
+version 1.121460
 
 =head1 SYNOPSIS
 
@@ -1391,4 +1391,4 @@ Copyright (C) 2010 by Graham Barr.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
